/*************************************************************************
***	Authentication, authorization, accounting + firewalling package
***	Copyright 1998-2002 Anton Vinokurov <anton@netams.com>
***	Copyright 2002-2008 NeTAMS Development Team
***	This code is GPL v3
***	For latest version and more info, visit this project web page
***	located at http://www.netams.com
***
*************************************************************************/
/* $Id: security.h,v 1.16 2009-08-01 09:23:54 anton Exp $ */

/////////////////////////////////////////////////////////////////////////////////////////
// Permissions Management ///////////////////////////////////////////////////////////////////

extern const char *permissions_list[256]; 
#define UPERM_NONE          0
#define UPERM_LOGIN_WEB     2
#define UPERM_SHOWSTAT_HIS  10  
#define UPERM_SHOWOBJ_HIS   12
#define UPERM_MODIFYOBJ_HIS 20
#define UPERM_SHOWSTAT_ALL  40  
#define UPERM_SHOWOBJ_ALL   42
#define UPERM_SHOWCONFIG    50
#define UPERM_RADIUS		55
#define UPERM_MODIFYOBJ_ALL 60
#define UPERM_MODIFYCONFIG  70
#define UPERM_LOGIN_INT     100
#define UPERM_SYSACTION     150
#define UPERM_ALL           255	 

extern char *enable_password;

void aPermissionsInit();
u_char aCheckPerm(Connection *conn, u_char perm);
int aAuth(char *login, char *password);
char* CryptWord(char *pwd);
int aEnable(char *s);
#ifdef HAVE_PAM
int aAuthPam(char *username, char *password);
#endif
